==> tine20-allinone_2020.03.4.tar.bz2: Filemanager/js/Filemanager-lang-sv_SE-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Filemanager **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Swedish (Sweden) (http://www.transifex.com/tine20/tine20/language/sv_SE/)\nLanguage: sv_SE\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Password for download required"
: ""

, "Submit"
: ""

, "File not found!"
: ""

, "Name"
: "Namn"

, "Size"
: "Storlek"

, "Last Modified"
: "Senast ändrad"

, "Description"
: "Beskrivning"

, "Folder, Folders"
: [
  ""
 ,"Mapp"

]
, "File, Files"
: [
  "Fil"
 ,"Filer"

]
, "Default behavior when double-clicking on a Row"
: ""

, "Defines which action should be executed by default when double-clicked."
: ""

, "Invalid Filename"
: ""

, "Content type"
: ""

, "path"
: "sökväg"

, "URL"
: ""

, "Password"
: "Lösenord"

, "Valid until"
: "Giltig t.o.m."

, "Send as e-mail"
: "Skicka som e-post"

, "Download"
: ""

, "Create Public Link"
: ""

, "Remove record"
: ""

, "Creating new Download Link..."
: "Skapar ny nedladdningslänk..."

, "Deleting Download Links..."
: "Raderar nedladdningslänkar..."

, "Deleting Download Link..."
: "Raderar nedladdningslänk..."

, "Created By"
: "Skapad Av "

, "Creation Time"
: "Skapad"

, "Expiration Time"
: ""

, "Access Count"
: ""

, "Last Modified Time"
: "Senast ändrad"

, "Last Modified By"
: "Senast ändrad av"

, "Revision"
: "Revision"

, "This folder has own revision settings"
: ""

, "Revision active"
: ""

, "Limit revision amount to"
: ""

, "Hold-back in months"
: ""

, "Upload Failed"
: "Uppladdning misslyckades"

, "It is not permitted to store files in this folder!"
: ""

, "Select a file"
: "Välj en fil"

, "Select files"
: ""

, "Select a folder"
: ""

, "Select folders"
: ""

, "Select an item"
: ""

, "Select items"
: ""

, "Checking ..."
: ""

, "Overwrite Existing File?"
: ""

, "Do you really want to overwrite the selected file?"
: ""

, "Tags"
: "Taggar"

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Indexed"
: ""

, "File contents is part of the search index"
: ""

, "Upload"
: "Ladda upp"

, "Open Data Safe"
: ""

, "Folder Up"
: "Mapp upp"

, "Close Data Safe"
: ""

, "Filemanager"
: "Filhanterare"

, "Save locally"
: "Spara lokalt"

, "Close"
: "Stäng"

, "Loading preview ..."
: ""

, "Edit folder"
: ""

, "edit file"
: ""

, "Public Links"
: ""

, "Type"
: "Typ"

, "Not yet indexed"
: ""

, "Modified By"
: "Ändrad av"

, "Enter description"
: "Fyll i beskrivning"

, "Service Unavailable"
: "Tjänst otillgänglig"

, "The Filemanager is not configured correctly. Please refer to the {0}Tine 2.0 Admin FAQ{1} for configuration advice or contact your administrator."
: "Filhanteraren är inte konfigurerad korrekt. Se {0} Tine 2,0 Admin FAQ {1} för konfigurations råd eller kontakta din administratör."

, "File(s) already exists"
: ""

, "Do you want to replace the following file(s)?"
: "Vill du ersätta följande fil(er)?"

, "An error occurred creating this folder"
: ""

, "Item with this name already exists!"
: "Ett objekt med detta namnet existerar redan!"

, "Whole Filemanager"
: ""

, "This Folder"
: "Denna mapp"

, "Search"
: "Sök"

, "The grant to download files"
: ""

, "Publish"
: ""

, "The grant to create anonymous download links for files"
: ""

, "Copying data .. {0}"
: "Kopierar data .. {0} "

, "Moving data .. {0}"
: "Flyttar data .. {0}"

, "Please wait"
: "Vänligen vänta"

, "Error while uploading \"{fileName}\". Please try again later."
: ""

, "Quick Search"
: "Snabbsök"

, "Content Type"
: ""

, "File Contents"
: ""

, "Download Link, Download Links"
: [
  ""
 ,""

]
, "Node Download Links"
: ""

, "Sorry, Tine 2.0 would have liked to show you the contents of the file."
: ""

, "This is possible for .doc, .jpg, .pdf and even more file formats."
: ""

, "Interested? Then let us know!"
: ""

, "We would be happy to make you a non-binding offer."
: ""

, "No preview available yet - Please try again in a few minutes."
: ""

, "Notifications"
: ""

, "This folder has own notification settings"
: ""

, "Notification"
: ""

, "Notification active"
: ""

, "Summary"
: ""

, "Once a Day, Every {0} Days"
: [
  ""
 ,""

]
, "No"
: ""

, "Don't summarize"
: ""

, "Once a day"
: ""

, "Every 3 days"
: ""

, "Once a week"
: ""

, "Once a month"
: ""

, "Once a year"
: ""

, "Search for users ..."
: ""

, "No permission"
: ""

, "all"
: "alla"

, "Search for groups ..."
: ""

, "Grants"
: ""

, "This folder has its own grants"
: ""

, "Grants of a folder also apply recursively to all sub folders unless they have their own grants."
: ""

, "This folder is part of the data safe"
: ""

, "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."
: ""

, "Usage"
: "Användning"

, "This folder has own quota"
: ""

, "Quota"
: "Quota"

, "No quota set (examples: 10 GB, 900 MB)"
: ""

, "Current Usage"
: "Nuvarande användning"

, "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."
: ""

, "File Type"
: ""

, "Usage by File Type"
: ""

, "User"
: ""

, "Usage by User"
: ""

, "unknown"
: ""

, "Reload"
: ""

, "Create Folder"
: "Skapa mapp"

, "New Folder"
: "Ny mapp"

, "Please enter the name of the new folder:"
: "Namnge den nya mappen:"

, "No {0} added"
: "Ingen {0} tillagd"

, "You have to supply a {0} name!"
: "Du måste ange ett {0} namn!"

, "Edit Properties"
: "Ändra egenskaper"

, "Rename"
: ""

, "Rename {0}"
: ""

, "Please enter the new name of the {0}:"
: "Var god ange det nya namnet för {0}:"

, "Not renamed {0}"
: "Ej omdöpt {0}"

, "System Link"
: ""

, "Use this link to share the entry with other system users"
: ""

, "Delete"
: "Radera"

, "Do you really want to delete the following files?"
: "Vill du verkligen radera följande filer?"

, "Move"
: "Flytta"

, "Move Items"
: "Flytta objekt"

, "Preview"
: ""

, "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."
: ""

, "Folder has been published successfully"
: ""

, "File has been published successfully"
: ""

, "Public Download URL"
: ""

, "Deliver anonymous downloads from another URL. Make sure the rewrite rules are adjusted accordingly."
: ""

, "you can't remove your own admin grant"
: ""

, "My folders"
: "Mina mappar"

, "Shared folders"
: "Delade mappar"

, "Other users folders"
: "Andra användares mappar"

, "Received"
: ""

, "To"
: "Till"

, "Cc"
: "Kopia"

, "Bcc"
: "Hemlig kopia"

, "From (E-Mail)"
: "Från (E-post)"

, "From (Name)"
: "Från (Namn)"

, "Body"
: ""

, "Attachments"
: "Bilagor"

, "Destination is a Subfolder"
: ""

, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
: ""

, "Destination has the same Path"
: ""

, "The destination has the same path as the source. No action has been performed."
: ""

, "manage shared folders"
: "hantera delade mappar"

, "Create new shared folders"
: "Skapa nya delade mappar"

, "Manage anonymous download links"
: ""

, "Allow viewing, adding and deleting download links"
: ""








, "Folder"
: ""

, "File"
: "Fil"

, "Download Link"
: ""

, "Once a Day"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Filemanager/js/Filemanager-lang-sv_SE-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Filemanager **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:53+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Swedish (Sweden) (http://www.transifex.com/tine20/tine20/language/sv_SE/)\nLanguage: sv_SE\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Usage"
: "Användning"

, "Size"
: "Storlek"

, "This folder has own quota"
: ""

, "Quota"
: "Quota"

, "No quota set (examples: 10 GB, 900 MB)"
: ""

, "Current Usage"
: "Nuvarande användning"

, "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."
: ""

, "Revision Size"
: ""

, "File Type"
: ""

, "Usage by File Type"
: ""

, "User"
: ""

, "Usage by User"
: ""

, "unknown"
: ""

, "Service Unavailable"
: "Tjänst otillgänglig"

, "The Filemanager is not configured correctly. Please refer to the {0}Tine 2.0 Admin FAQ{1} for configuration advice or contact your administrator."
: "Filhanteraren är inte konfigurerad korrekt. Se {0} Tine 2,0 Admin FAQ {1} för konfigurations råd eller kontakta din administratör."

, "File(s) already exists"
: ""

, "Do you want to replace the following file(s)?"
: "Vill du ersätta följande fil(er)?"

, "An error occurred creating this folder"
: ""

, "Item with this name already exists!"
: "Ett objekt med detta namnet existerar redan!"

, "Filemanager"
: "Filhanterare"

, "Save locally"
: "Spara lokalt"

, "Close"
: "Stäng"

, "Loading preview ..."
: ""

, "Node Download Links"
: ""

, "Create Public Link"
: ""

, "Remove record"
: ""

, "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."
: ""

, "Creating new Download Link..."
: "Skapar ny nedladdningslänk..."

, "Deleting Download Links..."
: "Raderar nedladdningslänkar..."

, "Deleting Download Link..."
: "Raderar nedladdningslänk..."

, "URL"
: ""

, "Created By"
: "Skapad Av "

, "Creation Time"
: "Skapad"

, "Expiration Time"
: ""

, "Password"
: "Lösenord"

, "Access Count"
: ""

, "Last Modified Time"
: "Senast ändrad"

, "Last Modified By"
: "Senast ändrad av"

, "Folder"
: ""

, "Total size of all available revisions"
: ""

, "File contents is part of the search index"
: ""

, "Upload"
: "Ladda upp"

, "Open Data Safe"
: ""

, "Folder Up"
: "Mapp upp"

, "Locking data safe..."
: ""

, "Unlocking data safe..."
: ""

, "Close Data Safe"
: ""

, "Upload Failed"
: "Uppladdning misslyckades"

, "It is not permitted to store files in this folder!"
: ""

, "Whole Filemanager"
: ""

, "This Folder"
: "Denna mapp"

, "Search"
: "Sök"

, "path"
: "sökväg"

, "Reload"
: ""

, "Create Folder"
: "Skapa mapp"

, "New Folder"
: "Ny mapp"

, "Please enter the name of the new folder:"
: "Namnge den nya mappen:"

, "No {0} added"
: "Ingen {0} tillagd"

, "You have to supply a {0} name!"
: "Du måste ange ett {0} namn!"

, "Edit Properties"
: "Ändra egenskaper"

, "Rename"
: ""

, "Rename {0}"
: ""

, "Please enter the new name of the {0}:"
: "Var god ange det nya namnet för {0}:"

, "Not renamed {0}"
: "Ej omdöpt {0}"

, "System Link"
: ""

, "Use this link to share the entry with other system users"
: ""

, "Delete"
: "Radera"

, "Do you really want to delete the following files?"
: "Vill du verkligen radera följande filer?"

, "Move"
: "Flytta"

, "Move Items"
: "Flytta objekt"

, "Preview"
: ""

, "Publish"
: ""

, "Folder has been published successfully"
: ""

, "File has been published successfully"
: ""

, "Notification"
: ""

, "Notification active"
: ""

, "Summary"
: ""

, "Once a Day, Every {0} Days"
: [
  ""
 ,""

]
, "No"
: ""

, "Don't summarize"
: ""

, "Once a day"
: ""

, "Every 3 days"
: ""

, "Once a week"
: ""

, "Once a month"
: ""

, "Once a year"
: ""

, "Name"
: "Namn"

, "Search for users ..."
: ""

, "No permission"
: ""

, "all"
: "alla"

, "Search for groups ..."
: ""

, "Valid until"
: "Giltig t.o.m."

, "Send as e-mail"
: "Skicka som e-post"

, "Download"
: ""

, "Revision"
: "Revision"

, "This folder has own revision settings"
: ""

, "Revision active"
: ""

, "Limit revision amount to"
: ""

, "Hold-back in months"
: ""

, "The grant to download files"
: ""

, "The grant to create anonymous download links for files"
: ""

, "Copying data .. {0}"
: "Kopierar data .. {0} "

, "Moving data .. {0}"
: "Flyttar data .. {0}"

, "Confirm Changing of Folder Grants"
: ""

, "You are about to move a folder which has own grants. These grants will be lost and the folder will inherit its grants from its new parent folder."
: ""

, "Please wait"
: "Vänligen vänta"

, "Error while uploading \"{fileName}\". Please try again later."
: ""

, "Download Link, Download Links"
: [
  ""
 ,""

]
, "Grants"
: ""

, "This folder has its own grants"
: ""

, "Grants of a folder also apply recursively to all sub folders unless they have their own grants."
: ""

, "This folder is part of the data safe"
: ""

, "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."
: ""

, "Select a file"
: "Välj en fil"

, "Select files"
: ""

, "Select a folder"
: ""

, "Select folders"
: ""

, "Select an item"
: ""

, "Select items"
: ""

, "Notifications"
: ""

, "This folder has own notification settings"
: ""

, "Edit folder"
: ""

, "edit file"
: ""

, "File"
: "Fil"

, "Public Links"
: ""

, "Type"
: "Typ"

, "Indexed"
: ""

, "Not yet indexed"
: ""

, "Modified By"
: "Ändrad av"

, "Last Modified"
: "Senast ändrad"

, "Description"
: "Beskrivning"

, "Enter description"
: "Fyll i beskrivning"

, "Sorry, Tine 2.0 would have liked to show you the contents of the file."
: ""

, "This is possible for .doc, .jpg, .pdf and even more file formats."
: ""

, "Interested? Then let us know!"
: ""

, "We would be happy to make you a non-binding offer."
: ""

, "This file has no contents. The Upload has failed or has not yet finished."
: ""

, "No preview available yet - Please try again in a few minutes."
: ""

, "Checking ..."
: ""

, "Overwrite Existing File?"
: ""

, "Do you really want to overwrite the selected file?"
: ""

, "Content type"
: ""

, "Public Download URL"
: ""

, "Deliver anonymous downloads from another URL. Make sure the rewrite rules are adjusted accordingly."
: ""

, "Destination has the same Path"
: ""

, "The destination has the same path as the source. No action has been performed."
: ""

, "Destination is a Subfolder"
: ""

, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
: ""

, "you can't remove your own admin grant"
: ""

, "My folders"
: "Mina mappar"

, "Shared folders"
: "Delade mappar"

, "Other users folders"
: "Andra användares mappar"

, "Received"
: ""

, "To"
: "Till"

, "Cc"
: "Kopia"

, "Bcc"
: "Hemlig kopia"

, "From (E-Mail)"
: "Från (E-post)"

, "From (Name)"
: "Från (Namn)"

, "Body"
: ""

, "Attachments"
: "Bilagor"

, "Password for download required"
: ""

, "Submit"
: ""

, "File not found!"
: ""

, "manage shared folders"
: "hantera delade mappar"

, "Create new shared folders"
: "Skapa nya delade mappar"

, "Manage anonymous download links"
: ""

, "Allow viewing, adding and deleting download links"
: ""








, "Once a Day"
: ""

, "Download Link"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
